BUILD_BIT='32bit'
BUILD_CPU='ARMv7 Processor rev 3 (v7l)'
BUILD_DATE='2020-04-05'
BUILD_MACHINE='armv7l'
BUILD_OS='Linux unknown unknown unknown'
BUILD_TIME='21:57'
COMPILER_VERSION='armv6l-unknown-linux-gnueabihf-gcc (GCC) 9.2.0'
CYTHON_VERSION='0.29.16'
LINKER_VERSION='GNU ld (GNU Binutils) 2.33.1'
PYTHON_VERSION='3.8.2'
RELEASE_BUILD=True
lib_gtk='3.24.17'
lib_vpx='1.8.2'
lib_x11='1.6.9'
lib_x264='0.159.2991'
lib_x265='3.3'
lib_xcomposite='0.4.5'
lib_xdamage='1.1.5'
lib_xext='1.3.4'
lib_xfixes='5.0.3'
lib_xkbfile='1.1.0'
lib_xrandr='1.5.2'
lib_xtst='1.2.3'
